@@ -1,24 +1,13 @@
 /******************************************************************************
-
   This source file is part of the Avogadro project.
-
-  Copyright 2008-2009 Marcus D. Hanwell
-  Copyright 2008 Albert De Fusco
-  Copyright 2010-2013 Kitware, Inc.
-
-  This source code is released under the New BSD License, (the "License").
-
-  Unless required by applicable law or agreed to in writing, software
-  distributed under the License is distributed on an "AS IS" BASIS,
-  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
-  See the License for the specific language governing permissions and
-  limitations under the License.
-
+  This source code is released under the 3-Clause BSD License, (see "LICENSE").
 ******************************************************************************/
 
 #ifndef AVOGADRO_CORE_GAUSSIANSETTOOLS_H
 #define AVOGADRO_CORE_GAUSSIANSETTOOLS_H
 
+#include "avogadrocoreexport.h"
+
 #include "avogadrocore.h"
 
 #include "basisset.h"
@@ -43,7 +32,7 @@ class Molecule;
 class AVOGADROCORE_EXPORT GaussianSetTools
 {
 public:
-  explicit GaussianSetTools(Molecule* mol = 0);
+  explicit GaussianSetTools(Molecule* mol = nullptr);
   ~GaussianSetTools();
 
   /**
@@ -65,12 +54,18 @@ public:
    * position specified.
    * @param position The position in space to calculate the value.
    * @param molecularOrbitalNumber The molecular orbital number.
-   * @param beta Whether to calculate beta electron or alpha/paired (default).
    * @return The value of the molecular orbital at the position specified.
    */
   double calculateMolecularOrbital(const Vector3& position,
                                    int molecularOrbitalNumber) const;
 
+  /**
+   * @brief Populate the cube with values for the electron density.
+   * @param cube The cube to be populated with values.
+   * @return True on success, false on failure.
+   */
+  bool calculateElectronDensity(Cube& cube) const;
+
   /**
    * @brief Calculate the value of the electron density at the position
    * specified.
@@ -79,6 +74,13 @@ public:
    */
   double calculateElectronDensity(const Vector3& position) const;
 
+  /**
+   * @brief Populate the cube with values for the spin density.
+   * @param cube The cube to be populated with values.
+   * @return True on success, false on failure.
+   */
+  bool calculateSpinDensity(Cube& cube) const;
+
   /**
    * @brief Calculate the value of the electron spin density at the position
    * specified.
