@@ -6,6 +6,8 @@
 #ifndef AVOGADRO_CORE_MOLECULE_H
 #define AVOGADRO_CORE_MOLECULE_H
 
+#include "avogadrocoreexport.h"
+
 #include "avogadrocore.h"
 
 #include "array.h"
@@ -136,6 +138,24 @@ public:
   /** \overload */
   const Array<signed char>& formalCharges() const;
 
+  /**
+   * Get the total charge on the molecule.
+   * The method will first check to see if a total charge has been set. If not,
+   * it will calculate the total charge from the formal charges (if set).
+   * If neither has been set, it will assume the total charge is zero.
+   * @return The total charge of the molecule.
+   */
+  signed char totalCharge() const;
+
+  /**
+   * Get the total spin multiplicity of the molecule.
+   * The method will first check to see if a total spin has been set. If not,
+   * it will either suggest a singlet if an even number of electrons are
+   * present, or a doublet if an odd number of electrons are present.
+   * @return The total spin multiplicity of the molecule.
+   */
+  char totalSpinMultiplicity() const;
+
   /**
    * Get the formal charge for the requested atom.
    * @param atomId The index of the atom.
@@ -159,7 +179,7 @@ public:
    */
   bool setFormalCharge(Index atomId, signed char charge);
 
-  /** Returns a vector of colors for the atoms in the moleucle. */
+  /** \returns a vector of colors for the atoms in the moleucle. */
   Array<Vector3ub>& colors();
 
   /** \overload */
@@ -506,9 +526,15 @@ public:
 
   /**
    * Perceives bonds in the molecule based on preset residue data.
+   *
+   * Use this if you have residue data available (e.g., reading PDB or MMTF
+   * files) Otherwise consider @sa perceiveBondsSimple and @sa
+   * perceiveBondOrders
    */
   void perceiveBondsFromResidueData();
 
+  void perceiveBondOrders();
+
   /**
    * Perceives all-carbon-substituted onium ions of nitrogen, oxygen,
    * phosphorus, sulfur, arsenic and selenium.
@@ -667,6 +693,26 @@ public:
    */
   bool setAtomicNumber(Index atomId, unsigned char atomicNumber);
 
+  /**
+   * Freeze or unfreeze an atom for optimization
+  */
+  void setFrozenAtom(Index atomId, bool frozen);
+
+  /**
+   * Get the frozen status of an atom
+  */
+  bool frozenAtom(Index atomId) const;
+
+  /**
+   * Freeze or unfreeze X, Y, or Z coordinate of an atom for optimization
+   * @param atomId The index of the atom to modify.
+   * @param axis The axis to freeze (0, 1, or 2 for X, Y, or Z)
+   * @param frozen True to freeze, false to unfreeze
+  */
+  void setFrozenAtomAxis(Index atomId, int axis, bool frozen);
+
+  Eigen::VectorXd frozenAtomMask() const { return m_frozenAtomMask; }
+
   /**
    * @return a map of components and count.
    */
@@ -692,9 +738,20 @@ public:
   Layer& layer();
   const Layer& layer() const;
 
+  /**
+   * Calculte and return bounding box of the whole molecule or selected atoms
+   * only.
+   * @param boxMin [out] the minimum corner (first end of the box diagonal)
+   * @param boxMax [out] the maximum corner (second end of the box diagonal)
+   * @param radius [in] radius of a single sphere
+   */
+  void boundingBox(Vector3& boxMin, Vector3& boxMax,
+                   const double radius = 1.0) const;
+
 protected:
   VariantMap m_data;
-  std::map<std::string, MatrixX> m_partialCharges; //!< Sets of atomic partial charges
+  std::map<std::string, MatrixX>
+    m_partialCharges; //!< Sets of atomic partial charges
   CustomElementMap m_customElementMap;
   ElementMask m_elements; //!< Which elements this molecule contains (e.g., for
                           //!< force fields)
@@ -726,6 +783,8 @@ protected:
   // This will be stored from the last space group operation
   unsigned short m_hallNumber = 0;
 
+  Eigen::VectorXd m_frozenAtomMask;
+
 private:
   mutable Graph m_graph; // A transformation of the molecule to a graph.
   // edge information
